import * as d3 from 'd3';

export const main = (container) => {
  const width = container.clientWidth;
  const height = container.clientHeight;

  const svg = d3
    .select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height)
    .style('background', '#F0FFF4');

  const radius = Math.min(width, height) / 2;

  const arc = d3
    .arc()
    .outerRadius(radius - 10)
    .innerRadius(radius - 30)
    .startAngle(0);

  const spinner = svg
    .append('g')
    .attr('class', 'spinner')
    .attr(
      'transform',
      `translate(${width / 2},${height / 2})`,
    );

  const progress = spinner
    .append('path')
    .datum({ endAngle: 0 })
    .attr('d', arc);

  function spin() {
    progress
      .transition()
      .duration(20000)
      .attrTween('d', function (d) {
        const interpolate = d3.interpolate(
          d.endAngle,
          Math.PI * 2,
        );
        return function (t) {
          d.endAngle = interpolate(t);
          return arc(d);
        };
      })
      .on('end', spin);
  }

  spin();
};
